@@ -1,11 +1,11 @@
 library(RcppCWB)
 
-testthat::context("cwb_id2str")
+testthat::context("cl_id2str")
 
 test_that(
   "id2str",
   {
-    token <- cwb_id2str(
+    token <- cl_id2str(
       corpus = "REUTERS",
       p_attribute = "word",
       registry = system.file(package = "RcppCWB", "extdata", "cwb", "registry"),
